==> beast-kit-generic-1.0.18-sources.jar: com/thebeastshop/common/exception/BaseServiceException.java <==
package com.thebeastshop.common.exception;

import org.apache.commons.lang3.StringUtils;
import java.io.File;
import java.util.HashMap;
import java.util.Map;

/**
 * 基础异常类
 * @author gongjun[jun.gong@thebeastshop.com]
 * @since 2017-04-26 11:10
 */
public class BaseServiceException extends RuntimeException {

    // 错误码
    private String errorCode;

    public BaseServiceException(final String errorCode) {
        super();
        this.errorCode = errorCode;
    }


    public BaseServiceException(final String errorCode, final Throwable cause) {
        this(errorCode, null, cause);
        this.errorCode = errorCode;
    }

    public BaseServiceException(final BaseErrorCode exceptionCode, final Throwable cause) {
        this(exceptionCode, exceptionCode.getErrorCode(), cause);
    }


    public BaseServiceException(final BaseErrorCode exceptionCode) {
        this(exceptionCode.getErrorCode(), exceptionCode.getMessage());
    }

    public BaseServiceException(final BaseErrorCode exceptionCode, final String msg) {
        this(exceptionCode.getErrorCode(), msg);
    }

    public BaseServiceException(final BaseErrorCode exceptionCode, final String msg, final Throwable cause) {
        this(exceptionCode.getErrorCode(), msg, cause);
    }

    public BaseServiceException(final String errorCode, final String msg) {
        super("[" + getAppId() + ":" + errorCode + "]" + msg);
        this.errorCode = errorCode;
    }

    public BaseServiceException(final String errorCode, final String msg, final Throwable cause) {
        super("[" + getAppId() + ":" + errorCode + "]" + msg, cause);
        this.errorCode = errorCode;
    }



    public String getErrorCode() {
        return errorCode;
    }

    public static String getAppId() {
        String str = System.getProperty("user.dir");
        if(StringUtils.isBlank(str)){
            return "[empty]";
        }
        String appId = str.substring(str.lastIndexOf(File.separator)+1);
        return appId;
    }

/*
    private static String errorMessage(final BaseErrorCode exceptionCode, final String msg) {
        if (StringUtils.isNotEmpty(msg)) {
            return exceptionCode.getMessage() + ": " + msg;
        }
        return exceptionCode.getMessage();
    }
*/

    public Map<String, Object> getErrorData() {
        return new HashMap<>();
    }
}

==> beast-kit-generic-1.2.1-sources.jar: com/thebeastshop/common/exception/BaseServiceException.java <==
package com.thebeastshop.common.exception;

import org.apache.commons.lang3.StringUtils;
import java.io.File;
import java.util.HashMap;
import java.util.Map;

/**
 * 基础异常类
 * @author gongjun[jun.gong@thebeastshop.com]
 * @since 2017-04-26 11:10
 */
public class BaseServiceException extends RuntimeException {

    // 错误码
    private String errorCode;

    public BaseServiceException(final String errorCode) {
        super();
        this.errorCode = errorCode;
    }


    public BaseServiceException(final String errorCode, final Throwable cause) {
        this(errorCode, null, cause);
        this.errorCode = errorCode;
    }

    public BaseServiceException(final BaseErrorCode exceptionCode, final Throwable cause) {
        this(exceptionCode, exceptionCode.getErrorCode(), cause);
    }


    public BaseServiceException(final BaseErrorCode exceptionCode) {
        this(exceptionCode.getErrorCode(), exceptionCode.getMessage());
    }

    public BaseServiceException(final BaseErrorCode exceptionCode, final String msg) {
        this(exceptionCode.getErrorCode(), msg);
    }

    public BaseServiceException(final BaseErrorCode exceptionCode, final String msg, final Throwable cause) {
        this(exceptionCode.getErrorCode(), msg, cause);
    }

    public BaseServiceException(final String errorCode, final String msg) {
//        super("[" + getAppId() + ":" + errorCode + "]" + msg);
        super(msg);
        this.errorCode = errorCode;
    }

    public BaseServiceException(final String errorCode, final String msg, final Throwable cause) {
        super("[" + getAppId() + ":" + errorCode + "]" + msg, cause);
        this.errorCode = errorCode;
    }



    public String getErrorCode() {
        return errorCode;
    }

    public static String getAppId() {
        String str = System.getProperty("user.dir");
        if(StringUtils.isBlank(str)){
            return "[empty]";
        }
        String appId = str.substring(str.lastIndexOf(File.separator)+1);
        return appId;
    }

/*
    private static String errorMessage(final BaseErrorCode exceptionCode, final String msg) {
        if (StringUtils.isNotEmpty(msg)) {
            return exceptionCode.getMessage() + ": " + msg;
        }
        return exceptionCode.getMessage();
    }
*/

    public Map<String, Object> getErrorData() {
        return new HashMap<>();
    }
}
